@@ -61,6 +61,7 @@
 #include <QPalette>
 #include <QPen>
 #include <QAction>
+#include <QActionGroup>
 #include <QBoxLayout>
 #include <QMenu>
 #include <QStyle>
@@ -483,7 +484,7 @@ void KateScrollBar::updatePixmap()
     savedLineColor.setHsv(savedLineColor.hue(), 100, 255 - backgroundColor.value() / 3);
 
     // increase dimensions by ratio
-    m_pixmap = QPixmap(pixmapLineWidth * m_view->devicePixelRatio(), pixmapLineCount * m_view->devicePixelRatio());
+    m_pixmap = QPixmap(pixmapLineWidth * m_view->devicePixelRatioF(), pixmapLineCount * m_view->devicePixelRatioF());
     m_pixmap.fill(QColor("transparent"));
 
     // The text currently selected in the document, to be drawn later.
@@ -605,7 +606,7 @@ void KateScrollBar::updatePixmap()
     }
 
     // set right ratio
-    m_pixmap.setDevicePixelRatio(m_view->devicePixelRatio());
+    m_pixmap.setDevicePixelRatio(m_view->devicePixelRatioF());
 
     //qCDebug(LOG_KTE) << time.elapsed();
     // Redraw the scrollbar widget with the updated pixmap.
@@ -2231,6 +2232,7 @@ void KateIconBorder::showMarkMenu(uint line, const QPoint &pos)
 
     QMenu markMenu;
     QMenu selectDefaultMark;
+    auto selectDefaultMarkActionGroup = new QActionGroup(&selectDefaultMark);
 
     QVector<int> vec(33);
     int i = 1;
@@ -2243,13 +2245,15 @@ void KateIconBorder::showMarkMenu(uint line, const QPoint &pos)
 
         QAction *mA;
         QAction *dMA;
+        const QPixmap icon = m_doc->markPixmap(markType);
         if (!m_doc->markDescription(markType).isEmpty()) {
-            mA = markMenu.addAction(m_doc->markDescription(markType));
-            dMA = selectDefaultMark.addAction(m_doc->markDescription(markType));
+            mA = markMenu.addAction(icon, m_doc->markDescription(markType));
+            dMA = selectDefaultMark.addAction(icon, m_doc->markDescription(markType));
         } else {
-            mA = markMenu.addAction(i18n("Mark Type %1",  bit + 1));
-            dMA = selectDefaultMark.addAction(i18n("Mark Type %1",  bit + 1));
+            mA = markMenu.addAction(icon, i18n("Mark Type %1",  bit + 1));
+            dMA = selectDefaultMark.addAction(icon, i18n("Mark Type %1",  bit + 1));
         }
+        selectDefaultMarkActionGroup->addAction(dMA);
         mA->setData(i);
         mA->setCheckable(true);
         dMA->setData(i + 100);
